@@ -12,22 +12,45 @@
 
 KNOWN_ATTRIBUTES = (
     'admin_state_up',
-    'id',
+    'allocation_pools',
+    'cidr',
+    'default_prefixlen',
+    'default_quota',
     'description',
+    'device_id',
+    'device_owner',
+    'dns_nameservers',
+    'enable_dhcp',
+    'fixed_ips',
+    'gateway_ip',
+    'host_routes',
+    'id',
+    'ip_version',
+    'ipv6_address_mode',
+    'ipv6_ra_mode',
+    'is_default',
+    'mac_address',
+    'max_prefixlen',
+    'min_prefixlen',
     'name',
     'network_id',
     'port_id',
+    'prefixes',
+    'prefixlen',
     'project_id',
     'shared',
     'status',
-    'tenant_id',
+    'subnets',
+    'subnetpool_id',
+    'tenant_id'
 )
 
 KNOWN_RESOURCES = (
     'networks',
     'ports',
-    'subnets',
     'routers',
+    'subnets',
+    'subnetpools'
 )
 
 KNOWN_HTTP_ACTIONS = (
@@ -37,6 +60,16 @@ KNOWN_HTTP_ACTIONS = (
     'PUT',
 )
 
+KNOWN_ACTION_STATUSES = (
+    200,
+    201,
+    202,
+    203,
+    204,
+    205,
+    206,
+)
+
 KNOWN_EXTENSIONS = (
     'address-scope',
     'agent',
@@ -87,6 +120,7 @@ KNOWN_EXTENSIONS = (
     'fwaas',
     'fwaasrouterinsertion',
     'fwaas_v2',
+    'bgpvpn',  # https://git.openstack.org/cgit/openstack/networking-bgpvpn
 )
 
 # The following is a short reference for understanding attribute info:
