@@ -89,6 +89,10 @@ ACTION_MAP = {
     }
 }
 
+# The action status.
+ACTION_STATUS = {
+}
+
 # The list of required extensions.
 REQUIRED_EXTENSIONS = [
     "binding",
